'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = {
  /**
   * Get the display name of a component
   * @param  {Object} Comp Specified Component
   * @return {String}      Display name of Component
   */
  getDisplayName: function getDisplayName(Comp) {
    if (!Comp) {
      return '';
    }
    if (typeof Comp === 'string') {
      return Comp;
    }
    return Comp.displayName || Comp.name || 'Component';
  },

  /*
   * 递归查找
   * Find and return all matched children by type. `type` can be a React element class or
   * string
   */
  findAllComponentByType: function findAllComponentByType(children, type) {
    var _this = this;

    var result = [];
    var types = [];

    if (_lodash2.default.isArray(type)) {
      types = type.map(function (t) {
        return _this.getDisplayName(t);
      });
    } else {
      types = [this.getDisplayName(type)];
    }

    _react2.default.Children.forEach(children, function (child) {
      var childType = child && child.type && (child.type.displayName || child.type.name);
      if (types.indexOf(childType) !== -1) {
        result.push(child);
      } else {
        if (child && child.props && child.props.children) {
          var result2 = _this.findAllByType(child.props.children, type);
          result2.forEach(function (v, k) {
            result.push(v);
          });
        }
      }
    });

    return result;
  }
};